/// FRANAGEM COM 3 CILINDROS DE VOLUME FIXO
/// 1a PARTE- MODELAGEM DO SIST PNEUMÁTICO
BCD = 0.56 // Diametro do tanque de frenagem
SLP = 0.18 // Altura do tanque de frenagem
TPL = 14 // Comprimento da linha no trem
BPL = 2 // Comprimento da linha paara o tanque de frenagem
TPD = 0.03 // Diâmetro dos tubos do trem
BPD = 0.03 // Diâmetro dos tubos que vão até os tanques 
AV = 18.325E-6 // Viscosidade do ar
T = 300 // Temperatura de operação
R = 0.287 // Constante do gás perfeito para o ar
PRH = 0.00015 // Rugosidade dos tubos
Patm = 101 // Pressão atmosférica
PI = 37 + Patm // Pressão inicial


/// CALCULOS INICIAIS

VBC = BCD^2*%pi/4*SLP // Volume do tanque de frenagem
VPC = TPD^2*%pi/4*TPL // Volume das linhas do trem
CB = VBC/(R*T) // Capacitância equivalente ao tanque de frenagem
CP = VPC/(R*T) // Capacitância equivalente às linhas do trem

/// SOLUÇÃO

function u = f(t,est)
    RHOB1 = est(1)/(R*T) // Calculo das densidades
    RHOB2 = est(2)/(R*T)
    RHOB3 = est(3)/(R*T)
    RHOT1 = est(4)/(R*T)
    RHOT2 = est(5)/(R*T)
    RHOT3 = est(6)/(R*T)
    RP1 = 128*AV*(TPL)/(%pi*TPD^4*RHOT1) // Cálculo das resistências equivalente aos volumes
    RP2 = 128*AV*(TPL)/(%pi*TPD^4*RHOT2)
    RP3 = 128*AV*(TPL)/(%pi*TPD^4*RHOT3)
    RT1 = 128*AV*(BPL)/(%pi*BPD^4*RHOB1)
    RT2 = 128*AV*(BPL)/(%pi*BPD^4*RHOB2)
    RT3 = 128*AV*(BPL)/(%pi*BPD^4*RHOB3)
    u1 = (est(4) - est(1))/(CB*RT1)
    u2 = (est(5) - est(2))/(CB*RT2)
    u3 = (est(6) - est(3))/(CB*RT3)
    u6 = (est(5) - est(6) - CB*((est(6) - est(3))/(CB*RT3))*RP3)/(CP*RP3)
    u5 = (est(4) - est(5) - CB*((est(6) - est(3))/(CB*RT3))*RP2 - CB*((est(5) - est(2))/(CB*RT2))*RP2 - CP*((est(5) - est(6) - CB*((est(6) - est(3))/(CB*RT3))*RP3)/(CP*RP3))*RP2)/(CP*RP2)
    u4 = (Pin(t) - est(4) - CB*((est(6) - est(3))/(CB*RT3))*RP1 - CB*((est(5) - est(2))/(CB*RT2))*RP1 - CB*((est(4) - est(1))/(CB*RT1))*RP1 - CP*((est(5) - est(6) - CB*((est(6) - est(3))/(CB*RT3))*RP3)/(CP*RP3))*RP1 - CP*((est(4) - est(5) - CB*((est(6) - est(3))/(CB*RT3))*RP2 - CB*((est(5) - est(2))/(CB*RT2))*RP2 - CP*((est(5) - est(6) - CB*((est(6) - est(3))/(CB*RT3))*RP3)/(CP*RP3))*RP2)/(CP*RP2))*RP1)/(CP*RP1)
    u = [u1;u2;u3;u4;u5;u6] 
endfunction

function p = Pin(t) // Função entrada 
    if t < 0.5 then
        p = PI
    else
        p = PI+200
    end
endfunction

/// CONDIÇÕES INICIAIS

P0 = [PI;PI;PI;PI;PI;PI]
/// PARÂMETROS DE TEMPO

t0 = 0 // Tempo inicial
tf = 180 // Tempo final
dt = 0.001 // Incremento de tempo
t = t0:dt:tf
intv= tf/dt
/// INTEGRAÇÃO

[P] = ode(P0,t0,t,f)


//2a PARTE- DESACELERACAO E ADICAO DO ATRITO

Af=0.073//área de sup da sapata em m2
M=80000*3// massa total do trem em kg 
mi=0.35// coef de atrito
ef=0.56//eficiencia etimoneira 
ra=5.13 //razao de alavancas
A=-1000*(Af*mi*ef*ra*(P(1,:)+P(2,:)+P(3,:)))/M  // matriz da aceleração 
Al=zeros(intv)
Ateste=-1000*(2*Af*mi*ef*(300))/M
for i= 1:intv
    Al(i)=A(1,i)
end

function y= ace(x,i) // funcao que retorna valores da aceleração
    y= Al(i)
    if x <0 then
        y=0
        
    end
endfunction

function dz=desacelera(t,z)
    z1= z(2)
    z2= ace(z(2),t+1)
    dz = [z1;z2] 
    
endfunction
yo=[0;16.67]
[Y] = ode( yo,t0,t,desacelera)

f2 = scf(2)
plot(t, Y(2,:),"r")
xtitle ("Velocidade de trem com 2 vagôes", "Tempo (s)", "velocidade(m/s)")

f2 = scf(4)
plot(Y(1,:), Y(2,:),"r")
xtitle ("Distancia percorrida por trem até frenagem", "deslocamento (m)", "velocidade(m/s)")








